A view of the Library’s String table
The inner raw reference refers to a continguous array of zero terminated strings.
The string table view is needed to arbitrarily access into the data and pull out the null terminated strings.
Attempts to patch plt entry at entry_addr.
Sets page protections containing entry_addr to PROT_WRITE | PROT_EXEC before replacing the pointer.
After writing out reverts the page to solely PROT_READ.
Returns the previous value contained in the entry_addr prior to patching.